previewInitiallyBound property
Whether or not preview has been bound to the lifecycle of the camera by createCamera.
Implementation
@visibleForTesting
bool previewInitiallyBound = false;
Whether or not preview has been bound to the lifecycle of the camera by createCamera.
@visibleForTesting
bool previewInitiallyBound = false;